/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.framework;

/**
 * Interface for generator extensions, which require singleton support (for variable declarations,,
 * initialization, and termination). Extension sharing the same singleton identifier returned by
 * {@link #getSingletonIdentifier()} will have their code contributions included only once.
 * 
 * @author hoelzl
 */
public interface ISingletonGeneratorExtension {
	/** Returns the singleton identifier. */
	String getSingletonIdentifier();

	/** Singleton postfix set by the code generator to ensure unique identifiers. */
	void setSingletonPostfix(String singletonPostfix);

	/**
	 * Returns the code to initialize local variables used by the code. Implementors may use the
	 * provided {@code singletonPostfix} to create unique variable names.
	 */
	String getSingletonVariableDeclarationCode();

	/** Returns the auxiliary function code needed by this executable. */
	String getSingletonAuxiliaryFunctions();

	/** Returns the common initialization code. */
	String getSingletonInitializationCode();

	/** Returns an termination code for the given {@code singletonPostfix}. */
	String getSingletonTerminationCode();
}
